Введение — СпамоБорец: документация

### Navigation

- index
- next |
- previous |
- СпамоБорец: документация »

# Введение

Сервер СпамоБорца предоставляет услуги по фильтрации входящих сообщений и выявлению в них спама, мата, флуда и прочих нежелательных элементов.

## Варианты размещения

Сервер может быть расположен удаленно по отношению к использующим его клиентам, в этой ситуации клиенты отправляют запросы серверу через сеть:

Такой вариант использования подойдет для относительно небольших проектов. Вы можете воспользоваться нашей инсталляцией СпамоБорца, которая поддерживается и обновляется нами. Если число обращений в сутки к серверу СпамоБорца будет меньше 2000, такое подключение производится бесплатно.

Или же сервер может быть расположен локально с сети кластера серверов проекта:

При такой установке вам потребуется установить СпамоБорец на один или несколько серверов, запустить его и поддерживать. Мы можем предоставить услуги по установке, поддержке и настройке СпамоБорца на ваших серверах.

### Navigation

- index
- next |
- previous |
- СпамоБорец: документация »